==> solid-bootstrap-core-0.2.2.tgz: package/esm/NavItem.jsx <==
import NavContext from "./NavContext";
import SelectableContext, { makeEventKey } from "./SelectableContext";
import { dataAttr } from "./DataKey";
import { createMemo, mergeProps, splitProps, useContext, } from "solid-js";
import { Dynamic } from "solid-js/web";
import { callEventHandler } from "./utils";
export function useNavItem(options) {
    const parentOnSelect = useContext(SelectableContext);
    const navContext = useContext(NavContext);
    const isActive = createMemo(() => options.active == null && options.key != null
        ? navContext?.activeKey === options.key
        : options.active);
    const role = createMemo(() => navContext && !options.role && navContext.role === "tablist"
        ? "tab"
        : options.role);
    const onClick = createMemo(() => (e) => {
        if (options.disabled)
            return;
        let result = callEventHandler(options.onClick, e);
        if (options.key == null) {
            return;
        }
        if (parentOnSelect && !result.isPropagationStopped) {
            parentOnSelect(options.key, e);
        }
    });
    const props = {
        get role() {
            return role();
        },
        get [dataAttr("event-key")]() {
            return navContext ? options.key : undefined;
        },
        get id() {
            return navContext ? navContext.getControllerId(options.key) : undefined;
        },
        get tabIndex() {
            return role() === "tab" && (options.disabled || !isActive())
                ? -1
                : undefined;
        },
        get ["aria-controls"]() {
            return navContext ? navContext.getControlledId(options.key) : undefined;
        },
        get ["aria-disabled"]() {
            return role() === "tab" && options.disabled ? true : undefined;
        },
        get ["aria-selected"]() {
            return role() === "tab" && isActive() ? true : undefined;
        },
        get onClick() {
            return onClick();
        },
    };
    const meta = {
        get isActive() {
            return isActive();
        },
    };
    return [props, meta];
}
const NavItem = (p) => {
    const [local, options] = splitProps(p, ["as", "active", "eventKey"]);
    const [props, meta] = useNavItem(mergeProps({
        get active() {
            return p.active;
        },
        get key() {
            return makeEventKey(p.eventKey, p.href);
        },
    }, options));
    // @ts-ignore
    props[dataAttr("active")] = meta.isActive;
    return (<Dynamic as={local.as} {...options} {...props}>
      {options.children}
    </Dynamic>);
};
NavItem.displayName = "NavItem";
export default NavItem;

==> solid-bootstrap-core-1.0.0.tgz: package/esm/NavItem.jsx <==
import NavContext from "./NavContext";
import SelectableContext, { makeEventKey } from "./SelectableContext";
import { dataAttr } from "./DataKey";
import { createMemo, mergeProps, splitProps, useContext } from "solid-js";
import { Dynamic } from "solid-js/web";
import { callEventHandler } from "./utils";
export function useNavItem(options) {
    const parentOnSelect = useContext(SelectableContext);
    const navContext = useContext(NavContext);
    const isActive = createMemo(() => options.active == null && options.key != null
        ? navContext?.activeKey === options.key
        : options.active);
    const role = createMemo(() => navContext && !options.role && navContext.role === "tablist" ? "tab" : options.role);
    const onClick = createMemo(() => (e) => {
        if (options.disabled)
            return;
        let result = callEventHandler(options.onClick, e);
        if (options.key == null) {
            return;
        }
        if (parentOnSelect && !result.isPropagationStopped) {
            parentOnSelect(options.key, e);
        }
    });
    const props = {
        get role() {
            return role();
        },
        get [dataAttr("event-key")]() {
            return navContext ? options.key : undefined;
        },
        get id() {
            return navContext ? navContext.getControllerId(options.key) : undefined;
        },
        get tabIndex() {
            return role() === "tab" && (options.disabled || !isActive()) ? -1 : undefined;
        },
        get ["aria-controls"]() {
            return navContext ? navContext.getControlledId(options.key) : undefined;
        },
        get ["aria-disabled"]() {
            return role() === "tab" && options.disabled ? true : undefined;
        },
        get ["aria-selected"]() {
            return role() === "tab" && isActive() ? true : undefined;
        },
        get onClick() {
            return onClick();
        },
    };
    const meta = {
        get isActive() {
            return isActive();
        },
    };
    return [props, meta];
}
const NavItem = (p) => {
    const [local, options] = splitProps(p, ["as", "active", "eventKey"]);
    const [props, meta] = useNavItem(mergeProps({
        get active() {
            return p.active;
        },
        get key() {
            return makeEventKey(p.eventKey, p.href);
        },
    }, options));
    // @ts-ignore
    props[dataAttr("active")] = meta.isActive;
    return (<Dynamic as={local.as} {...options} {...props}>
      {options.children}
    </Dynamic>);
};
NavItem.displayName = "NavItem";
export default NavItem;
